@@ -1,11 +1,11 @@
 #!/usr/bin/perl
 ### Project: Rambler.RU Command-line interface
-### File:    rambler-ru.pl
-### Creator: Artur Penttinen <artur@arto.inet.fi>
+### File:    Rambler-ru.pl
+### Creator: Artur Penttinen <artur+perl@niif.spb.su>
 ### Creation date: 12-08-2004 Thu 20:21:56 EEST
-### Last modified: <Thursday, 12-Aug-2004 20:35:47; artur>
+### Last modified: <Friday, 13-Aug-2004 01:06:01; artur>
 ###
-### $Id: rambler-ru.pl,v 1.3 2004/08/12 17:36:03 artur Exp $
+### $Id:$
 ###
 
 use strict;
@@ -15,24 +15,28 @@ use WWW::Search;
 use Text::Wrap;
 
 my $prg = $0; $prg =~ s|^.+/||;
-my $VERSION = '$Revision: 1.3 $'; $VERSION =~ s|[^\d.]+||g;
+my $VERSION = '$Revision:$'; $VERSION =~ s|[^\d.]+||g;
 
 my %opt;
 
-getopts ("hc:",\%opt);
+getopts ("hc:d:",\%opt);
 
 my $chset = $opt{'c'} || ($^O =~ m/win/i) ? "windows-1251" : "koi8-r";
+my $dbg = $opt{'d'} || 0;
 
 if (exists ($opt{'h'}) || !@ARGV) {
     print STDERR "usage: $prg {options} text\n";
     print STDERR "\t-h\t- this text\n";
     print STDERR "\t-c chset - character set [$chset]\n";
+    print STDERR "\t-d num\t- debug output [$dbg]\n";
     print STDERR "\n\t$prg version: $VERSION\n";
     exit;
 }
 
 my $search = new WWW::Search ("Rambler",'charset' => $chset);
 
+$search->{'_debug'} = $dbg;
+
 $search->native_query ("@ARGV");
 
 my $cnt = 0;
